@@ -45,7 +45,7 @@ class FetchResizeSave(object):
             self._progress = True
 
     def __enter__(self):
-        """Emtering a terminal window setup
+        """Entering a terminal window setup
         :return: self
         """
 
@@ -155,13 +155,13 @@ class FetchResizeSave(object):
                 break
         else:
             # run search again if validation removed some images
-            # and desired number of images is not reached
+            # and desired number of images hasn't been reached
             self.next_page(search_again=True)
 
         self._search_result = self._search_result[:self._number_of_images]
 
     def _search_images(self, search_params, path_to_dir=False, width=None,
-               height=None, cache_discovery=False):
+                       height=None, cache_discovery=False):
         """Fetched images using Google API and does the download and resize
         if path_to_dir and width and height variables are provided.
         :param search_params: parameters for Google API Search
@@ -174,12 +174,13 @@ class FetchResizeSave(object):
 
         i = 0
         threads = []
-        for url in self._google_custom_search.search(
+        for url, referrer_url in self._google_custom_search.search(
             search_params, cache_discovery
         ):
             # initialise image object
             image = GSImage(self)
             image.url = url
+            image.referrer_url = referrer_url
 
             # set thread safe variables
             self._download_progress[url] = 0
@@ -263,8 +264,10 @@ class FetchResizeSave(object):
             os.makedirs(path_to_dir)
 
         raw_filename = url.split('/')[-1].split('?')[0]
-        basename, _ = os.path.splitext(raw_filename)
-        ext = '.jpg'
+        basename, ext = os.path.splitext(raw_filename)
+
+        if not ext:
+            ext = '.jpg'
 
         if self._custom_image_name:
             def increment_naming(dir_list, name, number=0):
@@ -290,7 +293,8 @@ class FetchResizeSave(object):
                 f.write(chunk)
 
         try:
-            Image.open(path_to_image).convert('RGB').save(path_to_image, 'jpeg')
+            Image.open(path_to_image).convert('RGBA')\
+                .save(path_to_image, 'png')
         except UnidentifiedImageError:
             pass
 
@@ -302,7 +306,14 @@ class FetchResizeSave(object):
         :return: raw image data
         """
 
-        with requests.get(url, stream=True) as req:
+        # simulate browser request
+        headers = {
+            'User-Agent': 'Mozilla/5.0 (Windows NT 6.2; WOW64) '
+                          'AppleWebKit/537.36 (KHTML, like Gecko) '
+                          'Chrome/27.0.1453.94 '
+                          'Safari/537.36'
+        }
+        with requests.get(url, stream=True, headers=headers) as req:
             for chunk in req.iter_content(chunk_size=self._chunk_sizes.get(url)):
 
                 # filter out keep-alive new chunks
@@ -363,6 +374,7 @@ class GSImage(object):
 
         self._url = None
         self._path = None
+        self._referrer_url = None
 
         self.resized = False
 
@@ -400,6 +412,23 @@ class GSImage(object):
 
         self._path = image_path
 
+    @property
+    def referrer_url(self):
+        """Returns image referrer url
+        :return: referrer_url
+        """
+
+        return self._referrer_url
+
+    @referrer_url.setter
+    def referrer_url(self, referrer_url):
+        """Sets image referrer url
+        :param referrer_url: referrer url
+        :return: None
+        """
+
+        self._referrer_url = referrer_url
+
     def download(self, path_to_dir):
         """Downloads image from url to path
         :param path_to_dir: path
