@@ -28,6 +28,7 @@ class GoogleCustomSearch(object):
             'fileType': None,
             'safe': 'off',
             'imgDominantColor': None,
+            'imgColorType': None,
             'rights': None
         }
 
@@ -58,7 +59,10 @@ class GoogleCustomSearch(object):
 
         for key, value in self._search_params_keys.items():
             params_value = params.get(key)
+
             if params_value:
+                if key == "imgSize" and params_value != "imgSizeUndefined":
+                    params_value = params_value.upper()
                 # take user defined param value if defined
                 search_params[key] = params_value
             elif value:
@@ -83,15 +87,23 @@ class GoogleCustomSearch(object):
             self._fetch_resize_save.zero_return = True
 
         for image in results:
-
             if len(self._fetch_resize_save._search_result) >= \
-                    self._fetch_resize_save._number_of_images:
+                   self._fetch_resize_save._number_of_images:
                 break
 
             if self._fetch_resize_save.validate_images:
                 try:
+                    # simulate browser request
+                    headers = {
+                        'User-Agent': 'Mozilla/5.0 (Windows NT 6.2; WOW64) '
+                                      'AppleWebKit/537.36 (KHTML, like Gecko) '
+                                      'Chrome/27.0.1453.94 '
+                                      'Safari/537.36'
+                    }
                     response = requests.head(
-                        image['link'], timeout=5, allow_redirects=False)
+                        image['link'], timeout=5, allow_redirects=False,
+                        headers=headers
+                    )
                     content_length = response.headers.get('Content-Length')
                     content_type = response.headers.get('Content-Type', '')
 
@@ -103,15 +115,12 @@ class GoogleCustomSearch(object):
                         self._fetch_resize_save.set_chunk_size(
                             image['link'], content_length
                         )
-                except requests.exceptions.ConnectTimeout:
+                    else:
+                        continue
+                except requests.exceptions.RequestException:
                     continue
-                except requests.exceptions.ReadTimeout:
-                    continue
-                except requests.exceptions.SSLError:
-                    continue
-                except requests.exceptions.InvalidSchema:
-                    continue
-            yield image['link']
+
+            yield image['link'], image['image']['contextLink']
 
 
 class GoogleBackendException(Exception):
